Welcome to pymailai's documentation!
==================================

pymailai is a Python package that provides an email interface for AI agents.

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   quickstart
   api/index
   examples

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
